@@ -35,13 +35,13 @@ DefaultAction.prototype = new EAction();
 
 DefaultAction.State = {
     Neutral : 0,
-    Dragging : 1,
-    SettingCorner2 : 2,
-    MovingEntity : 3,
-    MovingEntityInBlock : 4,
-    SettingEntity : 5,
-    MovingReference : 6,
-    SettingReference : 7
+    Dragging : 1,               //*< Started dragging, minor distance, could be simple click at this stage
+    SettingCorner2 : 2,         //*< Setting 2nd corner of selection rectangle.
+    MovingEntity : 3,           //*< Dragging entity, mouse button is down.
+    MovingEntityInBlock : 4,    //*< Dragging entity inside block, mouse button is down.
+    SettingEntity : 5,          //*< Setting position of previously dragged entity, mouse button is up.
+    MovingReference : 6,        //*< Dragging reference point, mouse button is down.
+    SettingReference : 7        //*< Setting position of previously dragged reference point, mouse button is up.
 };
 
 DefaultAction.prototype.beginEvent = function() {
@@ -178,7 +178,7 @@ DefaultAction.prototype.mouseMoveEvent = function(event) {
             // if the dragging started on top of a reference point,
             // start moving the reference point:
             referencePoint = view.getClosestReferencePoint(this.d1Screen, this.minPickRangePixels);
-            if (referencePoint.isValid()) {
+            if (referencePoint.isValid() && !referencePoint.isIgnore() && !RSettings.getIgnoreAllReferencePoints()) {
                 this.d1Model = referencePoint;
                 this.di.setRelativeZero(this.d1Model);
                 this.setState(DefaultAction.State.MovingReference);
@@ -282,7 +282,9 @@ DefaultAction.prototype.mouseReleaseEvent = function(event) {
     if (event.button() === Qt.LeftButton) {
         switch (this.state) {
         case DefaultAction.State.Dragging:
-            entityId = this.getEntityId(event);
+            // find selectable entity under cursor:
+            entityId = this.getEntityId(event, false, true);
+            //qDebug("entityId: ", entityId);
 
             if (entityId !== -1) {
                 if (shiftPressed && this.document.isSelected(entityId)) {
@@ -342,22 +344,22 @@ DefaultAction.prototype.mouseReleaseEvent = function(event) {
         else if (this.state===DefaultAction.State.Neutral) {
             var appWin = EAction.getMainWindow();
             var rightClickRange = RSettings.getIntValue("GraphicsView/RightClickRange", 10);
-            entityId = EAction.getEntityIdUnderCursor(this.di, event, rightClickRange);
+            entityId = EAction.getEntityIdUnderCursor(this.di, event, rightClickRange, true);
 
             var rightClickToDeselect = RSettings.getBoolValue("GraphicsView/RightClickToDeselect", false);
 
             // right-click on entity can be used to show context menu:
             if (entityId!==-1) {
                 // show entity context menu:
-                var rightClickEntityContextMenu = RSettings.getBoolValue("ContextMenu/RightClickEntityContextMenu", false);
+                var rightClickEntityContextMenu = RSettings.getBoolValue("ContextMenu/RightClickEntityContextMenu", true);
                 if (rightClickEntityContextMenu) {
                     event.accept();
-                    appWin.showContextMenu(entityId);
+                    appWin.showContextMenu(entityId, event.getModelPosition());
                     handled = true;
                 }
 
                 // use right-click on entity to select entity:
-                if (rightClickToDeselect) {
+                else if (rightClickToDeselect) {
                     this.selectEntity(entityId, shiftPressed);
                     handled = true;
                 }
@@ -382,10 +384,11 @@ DefaultAction.prototype.mouseReleaseEvent = function(event) {
         }
 
         if (!handled) {
-            var rightClickContextMenu = RSettings.getBoolValue("ContextMenu/RightClickContextMenu", false);
+            // show context menu for empty space:
+            var rightClickContextMenu = RSettings.getBoolValue("ContextMenu/RightClickContextMenu", true);
             if (rightClickContextMenu===true) {
                 event.accept();
-                appWin.showContextMenu(RObject.INVALID_ID);
+                appWin.showContextMenu(RObject.INVALID_ID, event.getModelPosition());
             }
         }
     }
@@ -440,7 +443,8 @@ DefaultAction.prototype.pickCoordinate = function(event, preview) {
         var d2 = event.getModelPosition();
         if (shiftPressed) {
             var view = event.getGraphicsView();
-            var referenceEntityId = view.getClosestEntity(this.d1Screen, this.minPickRangePixels, 10, false, true);
+            var modelRange = view.mapDistanceFromView(this.minPickRangePixels);
+            var referenceEntityId = this.di.getClosestEntity(this.d1Model, modelRange, 10, false, true);
             if (referenceEntityId!==RObject.INVALID_ID) {
                 var e = doc.queryEntity(referenceEntityId);
                 if (!isNull(e)) {
@@ -603,6 +607,7 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
     }
     else if (isBlockReferenceEntity(entity)) {
         // in block text editing with double-click:
+        /*
         var blockId = entity.getReferencedBlockId();
         var block = this.document.queryBlock(blockId);
         if (!isNull(block)) {
@@ -629,6 +634,7 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
                 return;
             }
         }
+        */
 
         if (RSettings.getBoolValue("GraphicsView/DoubleClickEditBlock", true)===true) {
             include("scripts/Block/Block.js");
