@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2015 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2016 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -122,7 +122,7 @@ TextDialog.prototype.show =  function(textDataIn) {
     }
 
     this.dialog = WidgetFactory.createDialog(TextDialog.basePath, "TextDialog.ui", EAction.getMainWindow());
-    this.dialog.windowIcon = new QIcon(TextDialog.basePath + "/../Text.svg");
+    this.dialog.windowIcon = new QIcon(autoIconPath(TextDialog.basePath + "/../Text.svg"));
 
     // initialize dialog controls:
     this.textEdit = this.dialog.findChild("Text");
@@ -305,6 +305,8 @@ TextDialog.prototype.show =  function(textDataIn) {
             this.mode === TextDialog.Mode.AttributeDefinition) {
 
             this.dialog.findChild("AttributeTag").text = textDataIn.getTag();
+            this.dialog.findChild("AttributeValue").text = textDataIn.getText();
+
             if (this.mode === TextDialog.Mode.AttributeDefinition) {
                 this.dialog.findChild("AttributePrompt").text = textDataIn.getPrompt();
             }
@@ -312,8 +314,8 @@ TextDialog.prototype.show =  function(textDataIn) {
                 this.dialog.findChild("AttributePrompt").visible = false;
                 this.dialog.findChild("PromptLabel").visible = false;
                 this.dialog.findChild("AttributeTag").enabled = false;
+                this.dialog.findChild("AttributeValue").selectAll();
             }
-            this.dialog.findChild("AttributeValue").text = textDataIn.getText();
         }
     }
     else {
@@ -400,14 +402,9 @@ TextDialog.prototype.show =  function(textDataIn) {
     this.currentCharFormatChanged(this.textEdit.currentCharFormat());
     //this.colorChanged();
 
-    // exec text dialog:
-    if (!this.dialog.exec()) {
-        // dialog canceled:
-        this.dialog.destroy();
-        EAction.activateMainWindow();
-        return undefined;
-    }
 
+    // exec text dialog:
+    var res = this.dialog.exec();
     if (this.tabWidget.currentIndex===0) {
         this.updateSource(true);
     }
@@ -489,7 +486,12 @@ TextDialog.prototype.show =  function(textDataIn) {
     this.dialog.destroy();
     EAction.activateMainWindow();
 
-    return textDataOut;
+    if (res) {
+        return textDataOut;
+    }
+    else {
+        return undefined;
+    }
 };
 
 TextDialog.basePath = includeBasePath;
@@ -497,23 +499,23 @@ TextDialog.basePath = includeBasePath;
 TextDialog.prototype.setupEditActions = function() {
     var a;
 
-    a = this.actionUndo = new QAction(new QIcon(TextDialog.basePath + "/Undo.svg"), qsTr("&Undo"), this.dialog);
+    a = this.actionUndo = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Undo.svg")), qsTr("&Undo"), this.dialog);
     a.shortcut = QKeySequence.Undo;
     this.dialog.findChild("Undo").setDefaultAction(a);
 
-    a = this.actionRedo = new QAction(new QIcon(TextDialog.basePath + "/Redo.svg"), qsTr("&Redo"), this.dialog);
+    a = this.actionRedo = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Redo.svg")), qsTr("&Redo"), this.dialog);
     a.shortcut = QKeySequence.Redo;
     this.dialog.findChild("Redo").setDefaultAction(a);
 
-    a = this.actionCut = new QAction(new QIcon(TextDialog.basePath + "/Cut.svg"), qsTr("Cu&t"), this.dialog);
+    a = this.actionCut = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Cut.svg")), qsTr("Cu&t"), this.dialog);
     a.shortcut = QKeySequence.Cut;
     this.dialog.findChild("Cut").setDefaultAction(a);
 
-    a = this.actionCopy = new QAction(new QIcon(TextDialog.basePath + "/Copy.svg"), qsTr("&Copy"), this.dialog);
+    a = this.actionCopy = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Copy.svg")), qsTr("&Copy"), this.dialog);
     a.shortcut = QKeySequence.Copy;
     this.dialog.findChild("Copy").setDefaultAction(a);
 
-    a = this.actionPaste = new QAction(new QIcon(TextDialog.basePath + "/Paste.svg"), qsTr("&Paste"), this.dialog);
+    a = this.actionPaste = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Paste.svg")), qsTr("&Paste"), this.dialog);
     a.shortcut = QKeySequence.Paste;
     this.dialog.findChild("Paste").setDefaultAction(a);
 
@@ -521,7 +523,7 @@ TextDialog.prototype.setupEditActions = function() {
 };
 
 TextDialog.prototype.setupTextActions = function() {
-    this.actionTextBold = new QAction(new QIcon(TextDialog.basePath + "/Bold.svg"), qsTr("&Bold"), this.dialog);
+    this.actionTextBold = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Bold.svg")), qsTr("&Bold"), this.dialog);
     this.actionTextBold.shortcut = new QKeySequence(Qt.ControlModifier | Qt.Key_B);
     var bold = new QFont();
     bold.setBold(true);
@@ -530,7 +532,7 @@ TextDialog.prototype.setupTextActions = function() {
     this.actionTextBold.checkable = true;
     this.dialog.findChild("Bold").setDefaultAction(this.actionTextBold);
 
-    this.actionTextItalic = new QAction(new QIcon(TextDialog.basePath + "/Italic.svg"), qsTr("&Italic"), this.dialog);
+    this.actionTextItalic = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Italic.svg")), qsTr("&Italic"), this.dialog);
     this.actionTextItalic.shortcut = new QKeySequence(Qt.ControlModifier | Qt.Key_I);
     var italic = new QFont();
     italic.setItalic(true);
@@ -540,7 +542,7 @@ TextDialog.prototype.setupTextActions = function() {
     this.dialog.findChild("Italic").setDefaultAction(this.actionTextItalic);
 
     /*
-    this.actionTextUnderline = new QAction(new QIcon(TextDialog.basePath + "/Underline.svg"), qsTr("&Underline"), this.dialog);
+    this.actionTextUnderline = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Underline.svg")), qsTr("&Underline"), this.dialog);
     this.actionTextUnderline.shortcut = Qt.CTRL + Qt.Key_U;
     var underline = new QFont();
     underline.setUnderline(true);
@@ -550,24 +552,24 @@ TextDialog.prototype.setupTextActions = function() {
     this.dialog.findChild("Underline").setDefaultAction(this.actionTextUnderline);
     */
 
-    this.actionSubscript = new QAction(new QIcon(TextDialog.basePath + "/Subscript.svg"), qsTr("&Subscript"), this.dialog);
+    this.actionSubscript = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Subscript.svg")), qsTr("&Subscript"), this.dialog);
     this.actionSubscript.shortcut = new QKeySequence(Qt.ShiftModifier | Qt.ControlModifier | Qt.Key_B);
     this.actionSubscript.triggered.connect(this, "textSubscript");
     this.actionSubscript.checkable = true;
     this.dialog.findChild("Subscript").setDefaultAction(this.actionSubscript);
 
-    this.actionSuperscript = new QAction(new QIcon(TextDialog.basePath + "/Superscript.svg"), qsTr("&Superscript"), this.dialog);
+    this.actionSuperscript = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Superscript.svg")), qsTr("&Superscript"), this.dialog);
     this.actionSuperscript.shortcut = new QKeySequence(Qt.ShiftModifier | Qt.ControlModifier | Qt.Key_P);
     this.actionSuperscript.triggered.connect(this, "textSuperscript");
     this.actionSuperscript.checkable = true;
     this.dialog.findChild("Superscript").setDefaultAction(this.actionSuperscript);
 
-//    this.actionZoomIn = new QAction(new QIcon(TextDialog.basePath + "/ZoomIn.svg"), qsTr("Zoom &In"), this.dialog);
+//    this.actionZoomIn = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/ZoomIn.svg")), qsTr("Zoom &In"), this.dialog);
 //    this.actionZoomIn.shortcut = new QKeySequence(Qt.ControlModifier | Qt.Key_Plus);
 //    this.actionZoomIn.triggered.connect(this.textEdit, "zoomIn");
 //    this.dialog.findChild("ZoomIn").setDefaultAction(this.actionZoomIn);
 
-//    this.actionZoomOut = new QAction(new QIcon(TextDialog.basePath + "/ZoomOut.svg"), qsTr("Zoom &Out"), this.dialog);
+//    this.actionZoomOut = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/ZoomOut.svg")), qsTr("Zoom &Out"), this.dialog);
 //    this.actionZoomOut.shortcut = new QKeySequence(Qt.ControlModifier | Qt.Key_Minus);
 //    this.actionZoomOut.triggered.connect(this.textEdit, "zoomOut");
 //    this.dialog.findChild("ZoomOut").setDefaultAction(this.actionZoomOut);
@@ -578,9 +580,7 @@ TextDialog.prototype.setupTextActions = function() {
     this.actionTextColor.triggered.connect(this, "textColor");
     this.dialog.findChild("Color").setDefaultAction(this.actionTextColor);
 
-    this.actionTextSymbol = new QAction(
-            new QIcon(TextDialog.basePath + "/Symbol.svg"),
-            qsTr("&Special Characters..."), this.dialog);
+    this.actionTextSymbol = new QAction(new QIcon(autoIconPath(TextDialog.basePath + "/Symbol.svg")), qsTr("&Special Characters..."), this.dialog);
     this.actionTextSymbol.triggered.connect(this, "textSymbol");
     this.dialog.findChild("Symbol").setDefaultAction(this.actionTextSymbol);
     
@@ -842,8 +842,19 @@ TextDialog.prototype.textColor = function() {
     }
 
     var chosenColor = chosenAction.property("color");
-    if (!chosenColor.isValid()) {
-        // others: color dialog:
+    if (chosenColor.isValid()) {
+        if (chosenColor.isByLayer()) {
+            chosenColor = RColor.CompatByLayer;
+        }
+        else if (chosenColor.isByBlock()) {
+            chosenColor = RColor.CompatByBlock;
+        }
+        else {
+            chosenColor = new QColor(chosenColor.red(), chosenColor.green(), chosenColor.blue(), chosenColor.alpha());
+        }
+    }
+    else {
+        // custom color: show color dialog:
         chosenColor = QColorDialog.getColor(this.textEdit.textColor(), this.dialog);
         if (!chosenColor.isValid()) {
             // color dialog canceled:
@@ -851,19 +862,6 @@ TextDialog.prototype.textColor = function() {
         }
     }
 
-    //qDebug("chosenColor: ", chosenColor);
-
-    if (chosenColor.isByLayer()) {
-        chosenColor = RColor.CompatByLayer;
-    }
-    else if (chosenColor.isByBlock()) {
-        chosenColor = RColor.CompatByBlock;
-        //qDebug("chosen QColor: ", chosenColor);
-    }
-    else {
-        chosenColor = new QColor(chosenColor.red(), chosenColor.green(), chosenColor.blue(), chosenColor.alpha());
-    }
-
     var fmt = new QTextCharFormat();
     fmt.setForeground(chosenColor);
     this.mergeFormatOnWordOrSelection(fmt);
