@@ -52,8 +52,8 @@ function usage() {
           + "                                 scripts/autostart.js. Note that with this option,\n"
           + "                                 QCAD is not started but rather the application \n"
           + "                                 implemented in the given script.\n"
-          + "-config [path]                   Reads and stores settings to QCAD3.ini at the given\n"
-          + "                                 location instead of the default location.\n"
+          + "-config [path]                   Reads and stores settings in a configuration file\n"
+          + "                                 at the given location instead of the default location.\n"
           + "-enable-script-debugger          Enables the script debugger.\n"
           + "                                 NOT recommended as this may cause unexpected\n"
           + "                                 behavior when using QCAD.\n"
@@ -61,7 +61,6 @@ function usage() {
           + "-exec [script file] [options]    Executes the given script file directly\n"
           + "                                 after staring QCAD. Options after the script\n"
           + "                                 file are passed on to the script.\n"
-          + "-gui-css-file [CSS file]         Loads the specified CSS file.\n"
           + "-help                            Displays this help.\n"
           + "-locale [locale]                 Sets the locale to be used (overrides\n"
           + "                                 the language set in the preferences).\n"
@@ -70,6 +69,7 @@ function usage() {
           + "-no-show                         Use but don't display GUI.\n"
           + "-filter [filter]                 Opens the subsequent file(s) with the explicitly \n"
           + "                                 given import filter.\n"
+          + "-font-substitution A B           Substitute font A with font B.\n"
           + "-rescan                          Rescan scripts folder for new add-ons\n"
           + "-version                         Displays the application version.\n"
           + "-enable-xdata                    Enables XData (custom properties) support.\n"
@@ -104,8 +104,7 @@ function openFiles(args, createNew) {
 
     for (var i = 0; i < args.length; ++i) {
         // arguments with one parameter:
-        if (args[i] === "-gui-style" || args[i] === "-gui-css-file"
-            || args[i] === "-locale" || args[i] === "-autostart"
+        if (args[i] === "-locale" || args[i] === "-autostart"
             || args[i] === "-app-id" || args[i] === "-ignore"
             || args[i] === "-config") {
             // skip 2 arguments
@@ -219,24 +218,36 @@ function execScripts(args) {
             if (isNull(args[i])) {
                 break;
             }
-            // run existing action:
+
+            // check for existing action (e.g. "scripts/File/NewFile/NewFile.js"):
             var action = RGuiAction.getByScriptFile(args[i]);
+
+            // script is not an existing action:
             if (isNull(action)) {
-                // gui action might not exist yet for this script, create one:
-                var resPath = args[i];
-                action = new RGuiAction("");
-                if (!new QFileInfo(resPath).exists()) {
-                    resPath = ":/" + resPath;
-                }
-                if (!new QFileInfo(resPath).exists()) {
-                    action = undefined;
+                // include (run) script which might or might not be action:
+                var scriptFile = args[i];
+                var scriptFilePath = getAbsolutePathForArg(scriptFile);
+                if (new QFileInfo(scriptFilePath).exists()) {
+
+                    // including the script evaluates (runs) it:
+                    include(scriptFilePath);
+
+                    // check if script created a class of same name as file base name:
+                    var fi = new QFileInfo(scriptFile);
+                    var className = fi.baseName();
+                    if (!isNull(global[className])) {
+                        // gui action might not exist yet for this script, create one:
+                        action = new RGuiAction("");
+                        action.setScriptFile(scriptFilePath);
+                        action.setRequiresDocument(false);
+                    }
                 }
                 else {
-                    action.setScriptFile(resPath);
-                    action.setRequiresDocument(false);
+                    qWarning("script not found: ", args[i]);
                 }
             }
 
+            // script is action or created action:
             if (!isNull(action)) {
                 ++i;
                 // handle script arguments:
@@ -247,18 +258,6 @@ function execScripts(args) {
                 --i;
                 action.slotTrigger();
             }
-
-            else {
-                // include (run) script which is not an action:
-                var scriptFile = args[i];
-                var path = getAbsolutePathForArg(scriptFile);
-                if (new QFileInfo(path).exists()) {
-                    include(path);
-                }
-                else {
-                    qWarning("script not found: ", args[i]);
-                }
-            }
         }
         if (args[i] === "-quit") {
             RSettings.setQuitFlag();
@@ -425,10 +424,6 @@ function uninitAddOns(addOns) {
  * Loads the add-ons and starts QCAD.
  */
 function main() {
-    if (!isNull(qApp.applicationNameOverride)) {
-        qApp.applicationName = qApp.applicationNameOverride;
-    }
-
     var i;
     var filesToOpen = [];
 
@@ -460,7 +455,12 @@ function main() {
 
     // app name for ini file differs to avoid conflict with
     // older QCAD versions:
-    RSettings.setApplicationName("QCAD3");
+    // note that a plugin might have set a name override already:
+    if (!RSettings.hasApplicationNameOverride()) {
+        RSettings.setApplicationNameOverride("QCAD3");
+    }
+    // make sure settings file path is reinitialized:
+    RSettings.uninit();
 
     // alternative path for QCAD3.ini:
     for (i=1; i<args.length; ++i) {
@@ -513,8 +513,8 @@ function main() {
         var fi = new QFileInfo(configFile);
         if (fi.exists()) {
             var configPath = fi.absolutePath();
-            var configBak = configPath + QDir.separator + "QCAD3_old." + fi.suffix();
-            qDebug("Renaming old unversioned config file from '" + configPath + "' to '"+ configBak + "'");
+            var configBak = configPath + QDir.separator + fi.baseName() + "_old." + fi.suffix();
+            qDebug("Renaming old unversioned config file from '" + configFile + "' to '"+ configBak + "'");
             QFile.remove(configBak);
             QFile.rename(configFile, configBak);
         }
@@ -524,6 +524,18 @@ function main() {
     var fiSettings = new QFileInfo(RSettings.getQSettings().fileName());
     var isFirstStart = !fiSettings.exists();
 
+    var numPlugins = RPluginLoader.countPlugins();
+    var pluginInfo;
+
+    // look up app name override:
+    for (i=0; i<numPlugins; i++) {
+        pluginInfo = RPluginLoader.getPluginInfo(i);
+        var n = pluginInfo.get("NameOverride");
+        if (!isNull(n)) {
+            qApp.applicationName = n;
+        }
+    }
+
     // if locale is given, don't show first start dialog:
     if (isFirstStart && !QCoreApplication.arguments().contains("-locale")) {
         include("Widgets/FirstStart/FirstStart.js");
@@ -544,17 +556,34 @@ function main() {
             RSettings.setValue("LibraryBrowser/SourceList", librarySources);
         }
     }
-    
+
+    // theme:
+    applyTheme();
+
     // splash:
     var splash = undefined;
     if (RSettings.getBoolValue("Start/EnableSplashScreen", true)) {
         var fn;
+        var key;
         if (RSettings.getDevicePixelRatio()===2) {
+            key = "SplashOverride@2x";
             fn = "scripts/splashscreen@2x.png";
         }
         else {
+            key = "SplashOverride";
             fn = "scripts/splashscreen.png";
         }
+
+        // look up slash screen override:
+        for (i=0; i<numPlugins; i++) {
+            pluginInfo = RPluginLoader.getPluginInfo(i);
+            var s = pluginInfo.get(key);
+            if (!isNull(s)) {
+                fn = s;
+                qDebug("splash override: ", fn);
+            }
+        }
+
         var pixmap = new QPixmap(fn);
         splash = new QSplashScreen(pixmap);
         if (!QCoreApplication.arguments().contains("-no-show")) {
@@ -603,16 +632,19 @@ function main() {
 
     // create application window:
     var appWin = new RMainWindowQt();
-    // animated is nice, but crashes sometimes (Qt 4.7.2):
-    appWin.animated = false;
+    if (!RSettings.getQtVersionString().startsWith("5.7")) {
+        // animated crashes sometimes (Qt 4.7.2, 5.6.0):
+        // Qt 5.7.0 will not allow tabifying dock widgets if animations are turned off:
+        appWin.animated = false;
+    }
     appWin.objectName = "MainWindow";
     appWin.windowTitle = qApp.applicationName;
 
     // save first start information:
-    appWin.setProperty("FirstStart", isFirstStart);
+    RSettings.setFirstStart(isFirstStart);
     // save new version information:
-    appWin.setProperty("NewVersion", newVersion);
-    appWin.setProperty("PreviousVersion", previousVersion);
+    RSettings.setNewVersion(newVersion);
+    RSettings.setPreviousVersion(parseInt(previousVersion, 10));
 
     // save locale
     appWin.setProperty("Locale", RSettings.getLocale());
@@ -622,13 +654,13 @@ function main() {
     menuBar.objectName = "MenuBar";
 
     // load add-ons:
-    RDebug.startTimer(0);
+    //RDebug.startTimer(0);
     loadAddOns(addOns, splash);
-    RDebug.stopTimer(0, "loading add-ons");
+    //RDebug.stopTimer(0, "loading add-ons");
 
-    RDebug.startTimer(0);
+    //RDebug.startTimer(0);
     initAddOns(addOns, splash);
-    RDebug.stopTimer(0, "initializing add-ons");
+    //RDebug.stopTimer(0, "initializing add-ons");
 
     // auto load scripts in AutoLoad folders for global script engine:
     var files = RAutoLoadEcma.getAutoLoadFiles();
@@ -725,6 +757,10 @@ function main() {
     RPluginLoader.postInitPlugins(RPluginInterface.AllDone);
 
     appWin.setFocus();
+    var w = appWin.getMdiChild();
+    if (!isNull(w)) {
+        w.setFocus();
+    }
 
     if (!RSettings.hasQuitFlag()) {
         // start and enter the main application loop:
